@@ -18,6 +18,10 @@ class ItemCheckPipeline(object):
 
         oss_filename = item.get('oss_filename')
         if not oss_filename:
+            if unique_id.find('/') != -1:
+                msg = 'unique_id format error, find / in unicode_id'
+                spider.logger.error(msg)
+                raise DropItem(msg)
             oss_filename = f'{spider.name}/{unique_id}'
             item['oss_filename'] = oss_filename
         return item
